/*
The software in this package is distributed under the GNU General
Public License version 2 (with a special exception described below).

A copy of GNU General Public License (GPL) is included in this distribution,
in the file COPYING.GPL.

As a special exception, if other files instantiate templates or use macros
or inline functions from this file, or you compile this file and link it
with other works to produce a work based on this file, this file
does not by itself cause the resulting work to be covered
by the GNU General Public License.

However the source code for this file must still be made available
in accordance with section (3) of the GNU General Public License.

This exception does not invalidate any other reasons why a work based
on this file might be covered by the GNU General Public License.
*/
#ifndef HOST_H
#define HOST_H

#include <stdint.h>

#include <string>
#include <vector>

#include <boost/shared_ptr.hpp>

#include "host/pingprotocol.h"

//-----------------------------------------------------------------------------
// Host
//-----------------------------------------------------------------------------

/**
 * @brief This class holds the values for one host configured.
 */
class Host
{
public:
    Host( std::string address );
    ~Host();

    std::string get_address() const;
    void set_address( const std::string &address );

    uint16_t get_port() const;
    void set_port( const uint16_t port );

    std::string get_source_network_interface() const;
    void set_source_network_interface(
            const std::string &source_network_interface
    );

    PingProtocolList get_ping_protocol_list() const;
    void set_ping_protocol_list( const PingProtocolList &ping_protocol );

    int get_interval_in_sec() const;
    void set_interval_in_sec( const int interval_in_sec );

private:
    /// The address of the host
    std::string Address;
    /// The port of the host
    uint16_t Port;
    /// The network interface from where the pings will depart
    std::string SourceNetworkInterface;
    /// The list of protocols used to ping
    PingProtocolList ProtocolList;
    /// The interval between each ping to the host
    int IntervalInSec;

};

//-----------------------------------------------------------------------------
// HostItem
//-----------------------------------------------------------------------------

typedef boost::shared_ptr<Host> HostItem;

//-----------------------------------------------------------------------------
// HostList
//-----------------------------------------------------------------------------

typedef std::vector< HostItem > HostList;

#endif // HOST_H
